io.github.rutledgepaulv.newrelic-clj.api


async-transaction-fnclj

(async-transaction-fn f)
(async-transaction-fn f category name)

Instrument a function to produce a new function that will report to newrelic as a transaction if there is no parent transaction and as a child trace if there is already a parent transaction.

Instrument a function to produce a new function that will report to newrelic
as a transaction if there is no parent transaction and as a child trace if
there is already a parent transaction.
sourceraw docstring

defn-tracedcljmacro

(defn-traced & defnargs)

Like defn, but for defining functions that will report as newrelic transactions if there is no parent transaction, or as a trace if there already is a parent transaction.

Like defn, but for defining functions that will report as newrelic transactions
if there is no parent transaction, or as a trace if there already is a parent
transaction.
sourceraw docstring

get-async-tokenclj

(get-async-token)
(get-async-token transaction)

Get a token that can be used to connect traces back to a single transaction even if the traces run on different threads.

Get a token that can be used to connect traces back to a single transaction
even if the traces run on different threads.
sourceraw docstring

get-linking-contextclj

(get-linking-context)

Returns a map of data necessary to include in logs

Returns a map of data necessary to include in logs
sourceraw docstring

get-traceclj

(get-trace)
(get-trace transaction)

Get the current trace.

Get the current trace.
sourceraw docstring

get-transactionclj

(get-transaction)

Get the current transaction.

Get the current transaction.
sourceraw docstring

in-transaction?clj

(in-transaction?)
(in-transaction? transaction)

Check if there's already an active transaction

Check if there's already an active transaction
sourceraw docstring

mdc-context-fnclj

(mdc-context-fn f context)

Returns an instrumented version of f which will first establish a mdc context containing the data from the context map.

Returns an instrumented version of f which will first establish
a mdc context containing the data from the context map.
sourceraw docstring

notice-errorclj

(notice-error error)
(notice-error error data)

Reports an error to newrelic against the current transaction.

Reports an error to newrelic against the current transaction.
sourceraw docstring

omit-transactionclj

(omit-transaction)
(omit-transaction transaction)

Don't report the current transaction

Don't report the current transaction
sourceraw docstring

omit-transaction-errorsclj

(omit-transaction-errors)
(omit-transaction-errors transaction)

Don't report errors on the current transaction

Don't report errors on the current transaction
sourceraw docstring

omit-transaction-from-apdexclj

(omit-transaction-from-apdex)
(omit-transaction-from-apdex transaction)

Don't report the current transaction against the apdex

Don't report the current transaction against the apdex
sourceraw docstring

set-trace-nameclj

(set-trace-name category name)
(set-trace-name trace category name)

Set a category and name for the current trace.

Set a category and name for the current trace.
sourceraw docstring

set-trace-paramsclj

(set-trace-params prefix params)
(set-trace-params trace prefix params)

Set parameters onto the current trace

Set parameters onto the current trace
sourceraw docstring

set-transaction-nameclj

(set-transaction-name category name)
(set-transaction-name transaction category name)

Set a transaction category and name for the current transaction.

Set a transaction category and name for the current transaction.
sourceraw docstring

set-transaction-requestclj

(set-transaction-request request)
(set-transaction-request transaction request)

Set a ring request map as the web request for the current transaction.

Set a ring request map as the web request for the current transaction.
sourceraw docstring

set-transaction-responseclj

(set-transaction-response response)
(set-transaction-response transaction response)

Set a ring request map as the web response for the current transaction.

Set a ring request map as the web response for the current transaction.
sourceraw docstring

transaction-fnclj

(transaction-fn f)
(transaction-fn f category name)

Instrument a function to produce a new function that will report to newrelic as a transaction if there is no parent transaction and as a child trace if there is already a parent transaction.

Instrument a function to produce a new function that will report to newrelic
as a transaction if there is no parent transaction and as a child trace if
there is already a parent transaction.
sourceraw docstring

with-async-transactioncljmacro

(with-async-transaction & body)

Runs body in a newrelic async transaction if there is no parent transaction or as a trace if there already is a parent transaction.

Runs body in a newrelic async transaction if there is no parent transaction
or as a trace if there already is a parent transaction.
sourceraw docstring

with-mdc-linkingcljmacro

(with-mdc-linking & body)

Sets up a mdc context containing the attributes necessary for 'logs in context' before executing body.

Sets up a mdc context containing the attributes necessary for 'logs in context' before executing body.
sourceraw docstring

with-transactioncljmacro

(with-transaction & body)

Runs body in a newrelic transaction if there is no parent transaction or as a trace if there already is a parent transaction.

Runs body in a newrelic transaction if there is no parent transaction
or as a trace if there already is a parent transaction.
sourceraw docstring

wrap-rum-injectionclj

(wrap-rum-injection handler)
(wrap-rum-injection handler
                    {:keys [should-inject?]
                     :or {should-inject? inject/should-inject?}})

Middleware to detect html page responses and inject a preconfigured client side rum agent.

Middleware to detect html page responses and inject a preconfigured client side rum agent.
sourceraw docstring

wrap-transactionclj

(wrap-transaction handler)

Ring middleware to establish a web transaction if one doesn't exist.

Ring middleware to establish a web transaction if one doesn't exist.
sourceraw docstring

wrap-transaction-namingclj

(wrap-transaction-naming handler)

Middleware to assign a name to the current transaction based on the route that is accessed. Template urls are used instead of the raw uri where possible to improve transaction grouping. Template urls are detected for applications using compojure or reitit and falls back to just using plain uri. The NewRelic agent applies its own grouping of transactions under the hood and so even raw uris may be grouped.

Middleware to assign a name to the current transaction based on the route that is accessed.
Template urls are used instead of the raw uri where possible to improve transaction grouping.
Template urls are detected for applications using compojure or reitit and falls back to just
using plain uri. The NewRelic agent applies its own grouping of transactions under the hood
and so even raw uris may be grouped.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries